@@ -1,6 +1,7 @@
 # standard library
 import asyncio
 from dataclasses import dataclass
+from logging import getLogger
 from typing import (
     AsyncIterable,
     Awaitable,
@@ -24,6 +25,10 @@ TIMEOUT: Final[int] = 60
 N_CONCURRENT: Final[int] = 10
 
 
+# module-level logger
+logger = getLogger(__name__)
+
+
 # type hints
 S = TypeVar("S")
 T = TypeVar("T")
@@ -58,36 +63,37 @@ class Slack:
 
     async def _post(self, article: Article) -> Awaitable[None]:
         """Translate and post an article to Slack."""
-        article = await self.translator.translate(article)
-        payload = self._to_payload(article)
+        translated = await self.translator.translate(article)
+        payload = self._to_payload(article, translated)
 
         async with ClientSession() as client:
-            await client.post(self.webhook_url, json=payload)
+            async with client.post(self.webhook_url, json=payload) as resp:
+                logger.debug(f"{str(resp.url):.300}...")
 
         await asyncio.sleep(1.0)
 
-    def _to_payload(self, article: Article) -> Payload:
+    def _to_payload(self, original: Article, translated: Article) -> Payload:
         """Convert article to payload for Slack post."""
-        authors_ = ", ".join(article.authors)
         divider = self.divider()
-
-        title = self.header(self.plain_text(article.title))
-        authors = self.section(self.mrkdwn(f"*Authors:* {authors_}"))
-        summary = self.section(self.mrkdwn(f"*Summary:* {article.summary}"))
+        header = self.header(self.plain_text(translated.title))
+        title = self.section(self.mrkdwn(f"*Title:* {original.title}"))
+        authors = self.section(self.mrkdwn(f"*Authors:* {', '.join(original.authors)}"))
+        summary = self.section(self.mrkdwn(f"*Summary:* {translated.summary}"))
         buttons = self.actions(
             elements=[
                 self.button(
                     self.plain_text("View arXiv"),
-                    url=article.arxiv_url,
+                    url=original.arxiv_url,
                 ),
                 self.button(
                     self.plain_text("View PDF"),
-                    url=article.arxiv_url.replace("abs", "pdf"),
+                    url=original.arxiv_url.replace("abs", "pdf"),
                 ),
             ]
         )
 
-        return dict(blocks=[divider, title, authors, summary, buttons, divider])
+        blocks = [divider, header, title, authors, summary, buttons, divider]
+        return dict(text=translated.title, blocks=blocks)
 
     def __getattr__(self, type: str) -> Callable[[str], Payload]:
         """Generate a function to create elements of Slack payload."""
