@@ -5,6 +5,7 @@ from __future__ import annotations
 import asyncio
 from dataclasses import dataclass
 from datetime import datetime, timedelta
+from logging import getLogger
 from typing import AsyncIterable, Awaitable, Iterable, Optional, Sequence, Union
 
 
@@ -24,6 +25,10 @@ N_PER_REQUEST: Final[int] = 100
 SECOND: Final[timedelta] = timedelta(seconds=1)
 
 
+# module-level logger
+logger = getLogger(__name__)
+
+
 # data classes
 @dataclass
 class Search:
@@ -94,6 +99,7 @@ class Search:
 
         async def request(url: str, **params) -> Awaitable[str]:
             async with client.get(url, params=params) as resp:
+                logger.debug(resp.url)
                 return await resp.text()
 
         for start in range(0, self.n_max_articles, self.n_per_request):
